Genome
=============
.. image:: https://travis-ci.org/marigenhq/genome-py.svg?branch=master
  :target: https://travis-ci.org/marigenhq/genome-py
  :alt: Build Status
     
.. image:: https://codecov.io/gh/marigenhq/genome-py/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/marigenhq/genome-py
  :alt: codecov

.. image:: https://badge.fury.io/py/genome-py.svg
  :target: https://badge.fury.io/py/genome-py
  :alt: Pypi Version
  
.. image:: https://readthedocs.org/projects/genome-py/badge/?version=latest
  :target: https://genome-py.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status


Installing
==========

.. code-block:: shell

    pip install genome-py

Usage
=====

.. code-block:: python

    from genome import load
    genome = load('path/to/genome/data')
    # <Genome: SNPs=553190, name='data'>


Development
===========

`Data source`_

.. _Data source: https://my.pgp-hms.org/public_genetic_data?utf8=%E2%9C%93&data_type=23andMe&commit=Search

